# @Time     : 2021/5/27
# @Project  : f1z1-g
# @IDE      : PyCharm
# @Author   : Angel
# @Email    : 376355670@qq.com
class BaseError(Exception):
    pass


class NotFunctionError(Exception):
    pass


class NotAsyncFunctionError(Exception):
    pass
